@@ -55,7 +55,10 @@ def show_frame(data, cols, rows=1):
 
 
 def rb(timings):
-    timings = [x for x in timings if x < 8]
+    if isinstance(timings, list):
+        timings = [x for x in timings if x < 8]
+    elif isinstance(timings, str):
+        timings = [n for n, x in enumerate(timings[:8]) if x == "1"]
     show_frame([timings], 8)
 
 
