@@ -79,3 +79,11 @@ def f2c(f):
     """
     return int((f-32)*(5/9))
 
+
+def ppl():
+    """
+    東京の直近の降水確率を返す
+    6時間ごと
+    """
+    d = get_wf_json()
+    return [int(x) for x in d[0]["timeSeries"][1]["areas"][0]["pops"]]
\ No newline at end of file
